@@ -37,6 +37,7 @@ from .Variables import VariableManager, DataSet
 from ..desktop import exception_to_desktop, Desktop, force_close_desktop, release_desktop, get_version_env_variable
 from ..generic.LoadAEDTFile import load_entire_aedt_file
 from ..generic.general_methods import aedt_exception_handler
+from ..generic.list_handling import variation_string_to_dict
 from ..modules.Boundary import BoundaryObject
 
 try:
@@ -218,22 +219,6 @@ model_names = {
     "EMIT Design": "EMIT Design",
 }
 
-#TODO: refactor this to Generic ?
-def _variation_string_to_dict(variation_string):
-    """Helper function to convert a list of "="-separated strings into a dictionary
-
-    Returns
-    -------
-    dict
-    """
-    var_data = variation_string.split()
-    variation_dict = {}
-    for var in var_data:
-        pos_eq = var.find("=")
-        var_name = var[0:pos_eq]
-        var_value = var[pos_eq+1:].replace('\'', '')
-        variation_dict[var_name] = var_value
-    return variation_dict
 
 class Design(object):
     """Class Design. Contains all functions and objects connected to the active Project and Design"""
@@ -255,7 +240,6 @@ class Design(object):
 
     @aedt_exception_handler
     def __getitem__(self, variable_name):
-        assert variable_name in self.variable_manager.variables, "Variable {0} dies not exist !".format(variable_name)
         return self.variable_manager[variable_name].string_value
 
     @aedt_exception_handler
@@ -295,7 +279,6 @@ class Design(object):
         self.project_datasets = self._get_project_datasets()
         self.design_datasets = self._get_design_datasets()
 
-
     @property
     def project_properies(self):
         """ """
@@ -338,7 +321,7 @@ class Design(object):
     @property
     def aedt_version_id(self):
         """Property
-        
+
         :return: AEDT Version
 
         Parameters
@@ -376,6 +359,11 @@ class Design(object):
 
     @design_name.setter
     def design_name(self, new_name):
+        """
+        Property
+
+        :return: Change the name of the parent AEDT Design
+        """
         if ";" in new_name:
             new_name = new_name.split(";")[1]
         # src_dir = self.working_directory
@@ -400,7 +388,7 @@ class Design(object):
     @property
     def design_type(self):
         """Property
-        
+
         :return: Design Type
 
         Parameters
@@ -415,7 +403,7 @@ class Design(object):
     @property
     def project_name(self):
         """Property
-        
+
         :return: Project Name
 
         Parameters
@@ -430,7 +418,7 @@ class Design(object):
     @property
     def project_list(self):
         """Property
-        
+
         :return: List of available Projects
 
         Parameters
@@ -445,7 +433,7 @@ class Design(object):
     @property
     def project_path(self):
         """Property
-        
+
         :return: Project Path
 
         Parameters
@@ -460,7 +448,7 @@ class Design(object):
     @property
     def project_file(self):
         """Property
-        
+
         :return: Full absolute Project name and path
 
         Parameters
@@ -475,7 +463,7 @@ class Design(object):
     @property
     def lock_file(self):
         """Property
-        
+
         :return: Full absolute Project lock file
 
         Parameters
@@ -490,7 +478,7 @@ class Design(object):
     @property
     def results_directory(self):
         """Property
-        
+
         :return: Full absolute path of the aedtresults directory
 
         Parameters
@@ -505,7 +493,7 @@ class Design(object):
     @property
     def solution_type(self):
         """Property
-        
+
         :return: Solution Type
 
         Parameters
@@ -554,7 +542,7 @@ class Design(object):
     @property
     def valid_design(self):
         """Property
-        
+
         :return: True if oproject and odesign exists
 
         Parameters
@@ -569,7 +557,7 @@ class Design(object):
     @property
     def personallib(self):
         """Property
-        
+
         :return: Full absolute path of the PersonalLib directory
 
         Parameters
@@ -584,7 +572,7 @@ class Design(object):
     @property
     def userlib(self):
         """Property
-        
+
         :return: Full absolute path of the UserLib directory
 
         Parameters
@@ -599,7 +587,7 @@ class Design(object):
     @property
     def syslib(self):
         """Property
-        
+
         :return: Full absolute path of the SysLib directory
 
         Parameters
@@ -614,7 +602,7 @@ class Design(object):
     @property
     def src_dir(self):
         """Property
-        
+
         :return: Full absolute path of the python directory
 
         Parameters
@@ -629,7 +617,7 @@ class Design(object):
     @property
     def pyaedt_dir(self):
         """Property
-        
+
         :return: Full absolute path of the pyaedt Root Parent
 
         Parameters
@@ -644,7 +632,7 @@ class Design(object):
     @property
     def library_list(self):
         """Property
-        
+
         :return: list of [syslub, userlib, personallib]
 
         Parameters
@@ -659,7 +647,7 @@ class Design(object):
     @property
     def temp_directory(self):
         """Property
-        
+
         :return: Full absolute path of the TEMP directory
 
         Parameters
@@ -674,7 +662,7 @@ class Design(object):
     @property
     def toolkit_directory(self):
         """Property
-        
+
         :return: Full absolute path of the toolkit directory for this project - creates it if does not exist
 
         Parameters
@@ -692,7 +680,7 @@ class Design(object):
     @property
     def working_directory(self):
         """Property
-        
+
         :return: Full absolute path of the working directory for this project - creates it if does not exist
 
         Parameters
@@ -710,7 +698,7 @@ class Design(object):
     @property
     def default_solution_type(self):
         """Property
-        
+
         :return: Default solution type for the current application running
 
         Parameters
@@ -725,7 +713,7 @@ class Design(object):
     @property
     def odesign(self):
         """Property
-        
+
         :return: oDesign object
 
         Parameters
@@ -744,7 +732,7 @@ class Design(object):
         Parameters
         ----------
         des_name :
-            
+
 
         Returns
         -------
@@ -781,7 +769,7 @@ class Design(object):
     @property
     def oboundary(self):
         """Property
-        
+
         :return: BoundarySetup Module object
 
         Parameters
@@ -796,7 +784,7 @@ class Design(object):
     @property
     def omodelsetup(self):
         """Property
-        
+
         :return: ModelSetup Module object
 
         Parameters
@@ -812,7 +800,7 @@ class Design(object):
     @property
     def oimportexport(self):
         """Property
-        
+
         :return: ImportExport Module object
 
         Parameters
@@ -827,7 +815,7 @@ class Design(object):
     @property
     def oproject(self):
         """Property
-        
+
         :return: oProject object
 
         Parameters
@@ -886,7 +874,7 @@ class Design(object):
     @property
     def oanalysis_setup(self):
         """Property
-        
+
         :return: AnalysisSetup Module object
 
         Parameters
@@ -901,7 +889,7 @@ class Design(object):
     @property
     def odesktop(self):
         """Property
-        
+
         :return: oDesktop Module object
 
         Parameters
@@ -916,7 +904,7 @@ class Design(object):
     @property
     def desktop_install_dir(self):
         """Property
-        
+
         :return: AEDT Install Dir
 
         Parameters
@@ -931,7 +919,7 @@ class Design(object):
     @property
     def messenger(self):
         """Property
-        
+
         :return: Messenger object that can be used for logging on log file and on AEDT Message Windows
 
         Parameters
@@ -946,7 +934,7 @@ class Design(object):
     @property
     def variable_manager(self):
         """Property
-        
+
         :return: Variable maanager that can be used to create and manage Project, Design and PostProcessing Variables
 
         Parameters
@@ -965,11 +953,11 @@ class Design(object):
         Parameters
         ----------
         arg :
-            
+
         optimetrics_type :
-            
+
         variable_name :
-            
+
         min_val :
              (Default value = None)
         max_val :
@@ -1242,9 +1230,9 @@ class Design(object):
         Parameters
         ----------
         name :
-            
+
         datas :
-            
+
 
         Returns
         -------
@@ -1316,6 +1304,34 @@ class Design(object):
         release_desktop()
         return True
 
+    @aedt_exception_handler
+    def help(self, modulename="index"):
+        """
+        Launch Online help. Works on Windows Only (for linux manually launch it from Documentation folder)
+
+
+        :param modulename: name of the module or search string
+        :return: open default browser
+        """
+
+        filename = os.path.join(os.path.dirname(__file__), "Documentation", modulename+".html")
+        if os.path.exists(filename):
+            filepath = filename.replace(":\\", ":/").replace("\\", "/")
+            networkpath = "file:///" + filepath
+        else:
+            filename = os.path.dirname(__file__)+"/Documentation/search.html?q={}&".format(modulename)
+            filepath = filename.replace(":\\", ":/").replace("\\", "/")
+            paths = [r"C:\Program Files\Google\Chrome\Application\chrome.exe",
+                     r"C:\Program Files (x86)\Google\Chrome\Application\chrome.exe"]
+            networkpath = "file:///" + filepath
+            for p in paths:
+                if os.path.exists(p):
+                    os.system("start chrome " + networkpath)
+                    return True
+
+        webbrowser.open_new(networkpath)
+        return True
+
 
     @aedt_exception_handler
     def load_project(self, project_file, design_name=None, close_active_proj=False):
@@ -1541,7 +1557,7 @@ class Design(object):
         Parameters
         ----------
         ___________ :
-            
+
         material_override :
             bool (Default value = True)
         enable :
@@ -1578,15 +1594,15 @@ class Design(object):
 
         Returns
         -------
-        
+
             bool
 
         """
         self._messenger.add_info_message("Changing the validation design settings")
         self.odesign.SetDesignSettings(["NAME:Design Settings Data"],
-                                       ["NAME:Model Validation Settings", 
+                                       ["NAME:Model Validation Settings",
                                         "EntityCheckLevel:=", entity_check_level,
-                                        "IgnoreUnclassifiedObjects:=", ignore_unclassified, 
+                                        "IgnoreUnclassifiedObjects:=", ignore_unclassified,
                                         "SkipIntersectionChecks:=", skip_intersections])
         return True
 
@@ -1700,7 +1716,7 @@ class Design(object):
         Parameters
         ----------
         name :
-            
+
 
         Returns
         -------
@@ -1720,7 +1736,7 @@ class Design(object):
         Parameters
         ----------
         separator_name :
-            
+
 
         Returns
         -------
@@ -1831,7 +1847,7 @@ class Design(object):
         Parameters
         ----------
         design_name :
-            
+
 
         Returns
         -------
@@ -1930,7 +1946,7 @@ class Design(object):
         Parameters
         ----------
         label :
-            
+
 
         Returns
         -------
@@ -2105,9 +2121,8 @@ class Design(object):
 
     @aedt_exception_handler
     def get_evaluated_value(self, variable_name, variation=None):
-        """
-        Returns the floating-point evaluated value of a given variable
-        (design property or project variable) in SI-units
+        """Returns the floating-point evaluated value of a given variable in SI-units
+        (design property or project variable)
 
         Optionally a variation string of the form
 
@@ -2157,7 +2172,7 @@ class Design(object):
             return self._variable_manager.variables[expression_string]
         else:
             try:
-                self._variable_manager.set_variable("pyaedt_evaluator", expression=expression_string, prop_type="VariableProp",
+                self._variable_manager.set_variable("pyaedt_evaluator", expression=expression_string,
                                                     readonly=True, hidden=True, description="Internal_Evaluator")
             except:
                 raise("Invalid string expression {}".expression_string)
@@ -2182,21 +2197,18 @@ class Design(object):
         variation_string : str
         Variation string of the form "p1=1mm p2=3mm"
 
-            Parameters
-            ----------
-            variation_string
-
-            Returns
-            -------
+        Returns
+        -------
+        str
 
         """
         nominal = self._odesign.GetNominalVariation()
         if variation_string:
             # decompose the nominal variation into a dictionary of name[value]
-            nominal_dict = _variation_string_to_dict(nominal)
+            nominal_dict = variation_string_to_dict(nominal)
 
             # decompose the desired variation into a dictionary of name[value]
-            var_dict = _variation_string_to_dict(variation_string)
+            var_dict = variation_string_to_dict(variation_string)
 
             # set the values of the desired variation in the active design
             for key, value in var_dict.items():
@@ -2218,7 +2230,7 @@ class Design(object):
         Parameters
         ----------
         des_name :
-            
+
 
         Returns
         -------
