@@ -2,25 +2,21 @@
 Icepak 3d Layout Class
 ----------------------------------------------------------------
 
-
-Description
-==================================================
-
-This class contains all the Icepak AEDT Functionalities. It inherites all the objects that belongs to Icepak
+This class contains all Icepak functionalities. It inherits all objects that belong to Icepak.
 
 
-:Example:
+Examples:
 
-app = Icepak()     creates and Icepak object and connect to existing hfss design (create a new hfss design if not present)
+app = Icepak()     Creates an ``Icepak`` object and connects to an existing HFSS design or creates a new HFSS design if one is not present.
 
 
-app = Icepak(projectname)     creates and Icepak object and link to projectname project. If project doesn't exists, it creates a new one and rename it
+app = Icepak(projectname)     Creates an ``Icepak`` object and links to project named projectname. If this project doesn't exists, it creates a new one with this name.
 
 
-app = Icepak(projectname,designame)     creates and Icepak object and link to designname design in projectname project
+app = Icepak(projectname,designame)     Creates an ``Icepak`` object and links to a design named designname in a project named projectname.
 
 
-app = Icepak("myfile.aedt")     creates and Icepak object and open specified project
+app = Icepak("myfile.aedt")     Creates an ``Icepak`` object and opens the specified project.
 
 
 ========================================================
@@ -420,9 +416,8 @@ class Icepak(FieldAnalysisIcepak):
 
         Returns
         -------
-        type
+        bool
             Bool
-
         """
         temp_log = os.path.join(self.project_path, "validation.log")
         validate = self.odesign.ValidateDesign(temp_log)
@@ -557,7 +552,7 @@ class Icepak(FieldAnalysisIcepak):
         Fin_Line.append(self.Position('FinLength', 'FinThickness + FinLength*sin(PatternAngle*3.14/180)', 0))
         Fin_Line.append(self.Position('FinLength', 'FinLength*sin(PatternAngle*3.14/180)', 0))
         Fin_Line.append(self.Position(0, 0, 0))
-        self.modeler.primitives.create_polyline(Fin_Line, True, "Fin")
+        self.modeler.primitives.draw_polyline(Fin_Line, cover_surface=True, name="Fin")
         Fin_Line2 = []
         Fin_Line2.append(self.Position(0, 'sin(DraftAngle*3.14/180)*FinThickness', 'FinHeight'))
         Fin_Line2.append(self.Position(0, 'FinThickness-sin(DraftAngle*3.14/180)*FinThickness', 'FinHeight'))
@@ -567,7 +562,7 @@ class Icepak(FieldAnalysisIcepak):
         Fin_Line2.append(
             self.Position('FinLength', 'FinLength*sin(PatternAngle*3.14/180)+sin(DraftAngle*3.14/180)*FinThickness', 'FinHeight'))
         Fin_Line2.append(self.Position(0, 'sin(DraftAngle*3.14/180)*FinThickness', 'FinHeight'))
-        self.modeler.primitives.create_polyline(Fin_Line2, True, "Fin_top")
+        self.modeler.primitives.draw_polyline(Fin_Line2, cover_surface=True, name="Fin_top")
         self.modeler.connect(["Fin", "Fin_top"])
         self.assignmaterial("Fin", matname)
         # self.modeler.thicken_sheet("Fin",'-FinHeight')
@@ -604,7 +599,7 @@ class Icepak(FieldAnalysisIcepak):
             Center_Line.append(self.Position('VerticalSeparation', '-HSHeight-Tolerance', '-Tolerance'))
             Center_Line.append(self.Position('-VerticalSeparation', '-HSHeight-Tolerance', '-Tolerance'))
             Center_Line.append(self.Position('-SymSeparation', 'Tolerance', '-Tolerance'))
-            self.modeler.primitives.create_polyline(Center_Line, True, "Center")
+            self.modeler.primitives.draw_polyline(Center_Line, cover_surface=True, name="Center")
             self.modeler.thicken_sheet("Center", '-FinHeight-2*Tolerance')
             all_names = self.modeler.primitives.get_all_objects_names()
             list = [i for i in all_names if "Fin" in i]
